This data set was obtained by calculating the difference from the middle point of a zip code geometry to another zip code geometry (using the geo_postcodes4 data set and the sf package).
postcodes4_afstandenA data.frame with 1,123,600 observations and 3 variables:
postcode.x
zip code (PC4)
postcode.y
zip code (PC4)
afstand_km
distance in kilometres
The data in this data.frame are retrieved from, and publicly available at, Statistics Netherlands:
Centraal Bureau voor de Statistiek (CBS), 'Gebiedsindelingen', GPKG 2022 v1, https://www.cbs.nl
head(postcodes4_afstanden)
#> # A tibble: 6 × 3
#> postcode.x postcode.y afstand_km
#> <chr> <chr> <dbl>
#> 1 7702 7702 0
#> 2 7702 7705 3.04
#> 3 7702 7715 9.32
#> 4 7702 7741 14.4
#> 5 7702 7742 17.2
#> 6 7702 7751 18.4